﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;

namespace CurrentSL5
{
    public partial class SettingSelectionException : UserControl, INotifyPropertyChanged
    {
        private DateTime periodStart;
        private DateTime periodEnd;

        private DateTime visiblePeriodStart;
        private DateTime visiblePeriodEnd;

        public SettingSelectionException()
        {
            this.PeriodStart = new DateTime(2011, 1, 1);
            this.PeriodEnd = new DateTime(2011, 6, 1);

            this.VisiblePeriodStart = this.PeriodStart;
            this.VisiblePeriodEnd = this.VisiblePeriodStart.AddMonths(1);

            this.SelectionStart = this.PeriodStart;
            this.SelectionEnd = this.SelectionStart.AddDays(14);

            this.DataContext = this;

            InitializeComponent();

            this.SetSelectionDates(new DateTime(2011, 1, 20));
        }

        private DateTime _selectionStart;
        private DateTime _selectionEnd;

        public event PropertyChangedEventHandler PropertyChanged;

        public DateTime PeriodStart
        {
            get
            {
                return periodStart;
            }
            set
            {
                periodStart = value;
                OnPropertyChanged("PeriodStart");
            }
        }
        public DateTime PeriodEnd
        {
            get
            {
                return periodEnd;
            }
            set
            {
                periodEnd = value;
                OnPropertyChanged("PeriodEnd");
            }
        }

        public DateTime VisiblePeriodStart
        {
            get
            {
                return visiblePeriodStart;
            }
            set
            {
                visiblePeriodStart = value;
                OnPropertyChanged("VisiblePeriodStart");
            }
        }
        public DateTime VisiblePeriodEnd
        {
            get
            {
                return visiblePeriodEnd;
            }
            set
            {
                visiblePeriodEnd = value;
                OnPropertyChanged("VisiblePeriodEnd");
            }
        }

        public DateTime SelectionStart
        {
            get { return _selectionStart; }
            set
            {
                _selectionStart = value;
                OnPropertyChanged("SelectionStart");
            }
        }
        public DateTime SelectionEnd
        {
            get { return _selectionEnd; }
            set
            {
                _selectionEnd = value;
                OnPropertyChanged("SelectionEnd");
            }
        }

        private void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        private void SetSelectionDates(DateTime value)
        {
            TimeSpan ts = _selectionEnd - _selectionStart;
            int days = ts.Days;

            DateTime startDt = value;
            DateTime endDt = value.AddDays(days).AddHours(_selectionEnd.Hour).AddMinutes(_selectionEnd.Minute).AddSeconds(_selectionEnd.Second);

            bool doSelectionStartFirst = (_selectionEnd >= value);
            if (doSelectionStartFirst)
            {
                SelectionStart = startDt;
                SelectionEnd = endDt;
            }
            else
            {
                SelectionEnd = endDt;
                SelectionStart = startDt;
            }
        }
    }
}
